@@ -1,5 +1,5 @@
 ## plot_fun.R | ds4psy
-## hn | uni.kn | 2020 07 06
+## hn | uni.kn | 2021 03 31
 ## ---------------------------
 
 ## Functions for plotting. 
@@ -20,7 +20,6 @@ utils::globalVariables(c("x", "y", "char"))  # to avoid Warning NOTE "Undefined
 #' \code{plot_tiles} plots an area of \code{n-by-n} tiles 
 #' on fixed or polar coordinates.  
 #' 
-#' 
 #' @param n Basic number of tiles (on either side).
 #'
 #' @param pal Color palette (automatically extended to \code{n x n} colors). 
@@ -100,7 +99,6 @@ utils::globalVariables(c("x", "y", "char"))  # to avoid Warning NOTE "Undefined
 #' @import ggplot2
 #' @import grDevices 
 #' @import unikn
-#' @importFrom cowplot theme_nothing 
 #' 
 #' @export 
 
@@ -204,9 +202,10 @@ plot_tiles <- function(n = NA,
   # colors:
   cur_col <- pal_n_sq(n = n, pal = pal)
   
-  # Catch special case: Replace the white tile for n = 2 by a grau[[1]] tile:
+  # Special case: Replace a white tile for n = 2 by a grey tile:
   if (n == 2) { 
-    cur_col[cur_col == "#FFFFFF"] <- unikn::pal_grau[[1]] 
+    # print(cur_col)  # debugging
+    cur_col[cur_col == "#FFFFFF"] <- "#E1E2E5"  # HEX of unikn::pal_grau[[1]] 
   }
   
   # pick variables (in cur_tb):
@@ -247,8 +246,7 @@ plot_tiles <- function(n = NA,
     ggplot2::labs(title = "Tiles", x = "Data", y = "Science") +
     ## Colors: 
     ggplot2::scale_fill_gradientn(colors = cur_col) +  # s2: full unikn_sort palette: seeblau > white > black [default]
-    # theme_gray()
-    cowplot::theme_nothing()
+    theme_empty() # theme_gray() # cowplot::theme_nothing()
   
   if (lbl_title){
     
@@ -363,7 +361,8 @@ plot_tiles <- function(n = NA,
 #            sort = FALSE, borders = TRUE, 
 #            lbl_tiles = TRUE, lbl_title = TRUE, 
 #            rseed = 101)  # fix seed
-
+#
+# # Note: theme_empty() removed need for: #' @importFrom cowplot theme_nothing 
 
 
 ## plot_fun: Wrapper around plot_tiles (with fewer and cryptic options): -------- 
@@ -573,7 +572,6 @@ plot_fun <- function(a = NA,
 #' @import ggplot2
 #' @import grDevices
 #' @import unikn
-#' @importFrom cowplot theme_nothing 
 #' 
 #' @export 
 
@@ -722,9 +720,10 @@ plot_n <- function(n = NA,
   # cur_col <- pal_n_sq(n = n, pal = pal)  # use pal_n_sq helper function
   cur_col <- grDevices::colorRampPalette(colors = pal)(n)  # scale pal to length n
   
-  # Catch special case: Replace the white tile for n = 2 by a grau[[1]] tile:
+  # Special case: Replace a white tile for n = 2 by a grey tile:
   if (n == 2) { 
-    cur_col[cur_col == "#FFFFFF"] <- unikn::pal_grau[[1]] 
+    # print(cur_col)  # debugging
+    cur_col[cur_col == "#FFFFFF"] <- "#E1E2E5"  # HEX of unikn::pal_grau[[1]] 
   }
   
   # pick variables (in cur_tb):
@@ -767,8 +766,7 @@ plot_n <- function(n = NA,
       ggplot2::labs(title = "Tiles", x = "Data", y = "Science") +
       ## Colors: 
       ggplot2::scale_fill_gradientn(colors = cur_col) +  # s2: full unikn_sort palette: seeblau > white > black [default]
-      # theme_gray()
-      cowplot::theme_nothing()
+      theme_empty() # theme_gray() # cowplot::theme_nothing()
     
   } else { # as col: 
     
@@ -787,8 +785,7 @@ plot_n <- function(n = NA,
       ggplot2::labs(title = "Tiles", x = "Data", y = "Science") +
       ## Colors: 
       ggplot2::scale_fill_gradientn(colors = cur_col) +  # s2: full unikn_sort palette: seeblau > white > black [default]
-      # theme_gray()
-      cowplot::theme_nothing()
+      theme_empty() # theme_gray() # cowplot::theme_nothing()
     
   } # if (row) etc. 
   
@@ -961,10 +958,8 @@ plot_n <- function(n = NA,
 #        sort = FALSE, borders = TRUE,
 #        lbl_tiles = TRUE, lbl_title = TRUE,
 #        rseed = 101)  # fix seed
-
-
-
-
+#
+# # Note: theme_empty() removed need for: #' @importFrom cowplot theme_nothing 
 
 
 ## plot_fn: Wrapper around plot_n (with fewer and cryptic options): -------- 
@@ -1117,7 +1112,7 @@ plot_fn <- function(x = NA,
 #' @param pal Color palette for filling tiles 
 #' of text (used in order of character frequency). 
 #' Default: \code{pal = pal_ds4psy[1:5]} 
-#' (i.e., shades of \code{unikn::Seeblau}).  
+#' (i.e., shades of \code{Seeblau}).
 #' 
 #' @param pal_extend Boolean: Should pal be extended 
 #' to match the number of different characters in text? 
@@ -1189,7 +1184,6 @@ plot_fn <- function(x = NA,
 #' 
 #' @import ggplot2
 #' @importFrom grDevices colorRampPalette 
-#' @importFrom cowplot theme_nothing
 #' @importFrom stats runif
 #' 
 #' @export 
@@ -1328,7 +1322,6 @@ plot_text <- function(file = "",  # "" read from console; "test.txt" read from f
   #   message("plot_text: nr_char_freq differs from nr_chars.")
   # } 
   
-  
   # (4) Create color palette:
   if (pal_extend){
     
@@ -1381,7 +1374,6 @@ plot_text <- function(file = "",  # "" read from console; "test.txt" read from f
     char_angles <- 0
   }
   
-  
   # (6) Use ggplot2: 
   cur_plot <- ggplot2::ggplot(data = tb_txt, aes(x = x, y = y)) +
     ggplot2::geom_tile(aes(), fill = col_map, color = brd_col, size = brd_size,  # tiles (with borders, opt.)
@@ -1390,9 +1382,7 @@ plot_text <- function(file = "",  # "" read from console; "test.txt" read from f
                        fontface = fontface, family = family, angle = char_angles) + 
     ggplot2::coord_equal() + 
     # theme: 
-    # theme_classic() +
-    cowplot::theme_nothing()
-  
+    theme_empty() # theme_gray() # theme_classic() # cowplot::theme_nothing()
   
   # (7) plot plot: 
   cur_plot
@@ -1440,9 +1430,17 @@ plot_text <- function(file = "",  # "" read from console; "test.txt" read from f
 # plot_text()
 # 
 # }
+#
+# # Note: theme_empty() removed need for: #' @importFrom cowplot theme_nothing 
+
+
+## Done: ----------
+
+# - theme_empty() removed need for: #' @importFrom cowplot theme_nothing 
 
 ## ToDo: ----------
 
-# - Consider adding plot_tbar() and plot_tclock() (to plot toc, as in art.Rmd).
+# - Consider adding plot_tbar() and plot_tclock() 
+#   (to plot toc, see file images/art.Rmd).
 
 ## eof. ----------------------
\ No newline at end of file
